summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Guerry <bzg@altern.org>2012-07-11 18:03:02 +0200
committerBastien Guerry <bzg@altern.org>2012-07-11 18:03:02 +0200
commitbd4c629e96ce0f437d0ce28bec4ca794604841a2 (patch)
tree4a5658bdf597a02d9d0f58715846595ca906767a
parent97e001e88e8eb4f097702a92e7d7a55e47d7f6ed (diff)
downloadorg-mode-bd4c629e96ce0f437d0ce28bec4ca794604841a2.tar.gz
Fix docstring and comment typos.
* org-docbook.el (org-export-docbook-emphasis-alist): Fix typo: use "format string" instead of "formatting string". * org-latex.el (org-export-latex-emphasis-alist) (org-export-latex-title-command, org-export-latex-tables): Ditto. * org-html.el (org-export-html-postamble): Ditto.
-rw-r--r--lisp/org-docbook.el2
-rw-r--r--lisp/org-html.el2
-rw-r--r--lisp/org-latex.el6
3 files changed, 5 insertions, 5 deletions
diff --git a/lisp/org-docbook.el b/lisp/org-docbook.el
index cf73d1d..1187885 100644
--- a/lisp/org-docbook.el
+++ b/lisp/org-docbook.el
@@ -163,7 +163,7 @@ avoid same set of footnote IDs being used multiple times."
"A list of DocBook expressions to convert emphasis fontifiers.
Each element of the list is a list of three elements.
The first element is the character used as a marker for fontification.
-The second element is a formatting string to wrap fontified text with.
+The second element is a format string to wrap fontified text with.
The third element decides whether to protect converted text from other
conversions."
:group 'org-export-docbook
diff --git a/lisp/org-html.el b/lisp/org-html.el
index c9c9d78..a2cf2c7 100644
--- a/lisp/org-html.el
+++ b/lisp/org-html.el
@@ -408,7 +408,7 @@ like that: \"%%\"."
(defcustom org-export-html-postamble 'auto
"Non-nil means insert a postamble in HTML export.
-When `t', insert a string as defined by the formatting string in
+When `t', insert a string as defined by the format string in
`org-export-html-postamble-format'. When set to a string, this
string overrides `org-export-html-postamble-format'. When set to
'auto, discard `org-export-html-postamble-format' and honor
diff --git a/lisp/org-latex.el b/lisp/org-latex.el
index 53a5349..61ca74b 100644
--- a/lisp/org-latex.el
+++ b/lisp/org-latex.el
@@ -235,7 +235,7 @@ are written as utf8 files."
"Alist of LaTeX expressions to convert emphasis fontifiers.
Each element of the list is a list of three elements.
The first element is the character used as a marker for fontification.
-The second element is a formatting string to wrap fontified text with.
+The second element is a format string to wrap fontified text with.
If it is \"\\verb\", Org will automatically select a delimiter
character that is not in the string. \"\\protectedtexttt\" will use \\texttt
to typeset and try to protect special characters.
@@ -247,7 +247,7 @@ conversions."
(defcustom org-export-latex-title-command "\\maketitle"
"The command used to insert the title just after \\begin{document}.
If this string contains the formatting specification \"%s\" then
-it will be used as a formatting string, passing the title as an
+it will be used as a format string, passing the title as an
argument."
:group 'org-export-latex
:type 'string)
@@ -2033,7 +2033,7 @@ The conversion is made depending of STRING-BEFORE and STRING-AFTER."
(when org-table-clean-did-remove-column
(pop org-table-last-alignment)
(pop org-table-last-column-widths))
;; make a formatting string to reflect alignment
(setq olines lines)
(while (and (not line-fmt) (setq line (pop olines)))
(unless (string-match "^[ \t]*|-" line)
@@ -2033,7 +2033,7 @@ The conversion is made depending of STRING-BEFORE and STRING-AFTER."
(pop org-table-last-alignment)
(pop org-table-last-column-widths))
- ;; make a formatting string to reflect alignment
+ ;; make a format string to reflect alignment
(setq olines lines)
(while (and (not line-fmt) (setq line (pop olines)))